{% extends 'base.html' %}

{% block title %}
Logs ({{vars["log_count"]}})
{% endblock %}

{% block body %}
{% block log_table %}
<div class="container">
    <h1>Logs</h1>
    <table class="table">
        <thead>
            <tr class="table">
                <th scope="col">Date</th>
                <th scope="col">Time</th>
                <th scope="col"></th>
            </tr>
        </thead>
        <tbody class="table-group-divider">
            {% for _ in vars["log_list"] %}
            {% set date, time = _[0].split('T') %}
            <tr class="table  align-middle">
                <td>{{date|formatdate}}</td>
                <td>{{time|formattime}}</td>
                <td><a href="/trash-log/{{_[0]}}"><button type="submit" name="deletelog" id="deletelog"
                            class="btn btn-danger p-3 rounded-circle"><i class="bi bi-trash3"></i></button></a>
                </td>
            </tr>
            {% endfor %}
        </tbody>
    </table>
</div>
{% endblock %}
{% endblock %}