APP_NAME = "KTU Mon"
VERSION = "1.0.0"
DB_NAME = "ktu_mon"
SYSTRAY_ICON_FILENAME = "ktu-mon-32x32.ico"
PAGE_URL = "https://ktu.edu.in/eu/core/announcements.htm"
TABLE_CLASS = "ktu-news"
DATE_CLASS = "news-date"
PROC_ID_INITIALIZER = 1
PROC_ID_SYSTRAY = 2
PROC_ID_WEBGUI = 3
PROC_ID_TIMER = 4
